def  schoolName():
     return f"Future Campus School" 

def  principalName(): 
     return f"Partha Pratim Panja" 

def rectorName(): 
      return f"Arindam Banerjee" 

def computerTeachers(): 
      return f"Ananta kr Ghosh,DP sir,Priyanka Madam"

def coordinators(): 
      return f"Debapriya madam,aparna madam,Jyotirmoy sir"      
      



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='fcsSchool',
    version='0.0.2',
    description='A very basic description',
    long_description=open('README.txt').read(),
    url='',  # Replace with a valid URL or remove this line if not available
    author='A K Ghosh',
    author_email='anantafcs@gmail.com',
    license='MIT',
    classifiers=classifiers,
    keywords='FutureCampusSchool',
    packages=find_packages(),
    install_requires=[]  # Update with actual dependencies or leave as an empty list
)

